netapp_ontap.models.aggregate_space_snapshot API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_space_snapshot`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateSpaceSnapshotSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateSpaceSnapshot object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available: Size GET`

    Available space for snapshots in bytes

    Example: 2000

  `reserve_percent: Size GET`

    Percentage of space reserved for snapshots

    Example: 20

  `total: Size GET`

    Total space for snapshots in bytes

    Example: 5000

  `used: Size GET`

    Space used by snapshots in bytes

    Example: 3000

  `used_percent: Size GET`

    Percentage of disk space used by snapshots

    Example: 45